import numpy as np

from scipy.fftpack import dct

import matplotlib.pyplot as plt
import gp_emulator


np.random.seed(1)

n_validate = 250
n_train = 100
basis_functions = dct(np.eye(128), norm="ortho")[:, 1:4]

params=["w1", "w2", "w3"]
mins = [-1, -1, -1]
maxs = [1, 1, 1]


train_weights, dists = gp_emulator.create_training_set(params, mins, maxs,
                                                        n_train=n_train)
validation_weights = gp_emulator.create_validation_set(dists,
                                                    n_validate=n_validate)

training_set = (train_weights@basis_functions.T).T

training_set += np.random.randn(*training_set.shape)*0.0005
validation_set = (validation_weights@basis_functions.T).T

gp = gp_emulator.MultivariateEmulator (y=train_weights, X=training_set.T,
                                        thresh=0.973, n_tries=25)
y_pred = np.array([gp.predict(validation_weights[i])[0]
                        for i in range(n_validate)])

fig, axs = plt.subplots(nrows=1, ncols=2,sharey=True,figsize=(12, 4))
axs[0].plot(validation_set[:, ::25])
axs[1].plot(10.*(y_pred.T - validation_set))
axs[0].set_title("Samples from validation dataset")
axs[1].set_title("10*Mismatch between validation simulator and emulator")